@@ -10,6 +10,7 @@ for the Microsoft Visual Studio.
 
 import sys
 import os
+import warnings
 from distutils.errors import (
     DistutilsExecError,
     DistutilsPlatformError,
@@ -62,6 +63,14 @@ if _can_read_reg:
     )
 
 
+warnings.warn(
+    "msvccompiler is deprecated and slated to be removed "
+    "in the future. Please discontinue use or file an issue "
+    "with pypa/distutils describing your use case.",
+    DeprecationWarning,
+)
+
+
 def read_keys(base, key):
     """Return list of registry keys."""
     try:
